Patrick Georgi (pgeorgi(a)google.com) just uploaded a new patch set to gerrit, which you can find at https://review.coreboot.org/12683
-gerrit
commit 340062357df701a6e6cb806bda409e2d56d18ea9
Author: Patrick Georgi <pgeorgi(a)chromium.org>
Date: Mon Dec 7 23:14:07 2015 +0100
cbfstool: make top-aligned address work per-region
The former interpretation sprung from the x86 way of doing things
(assuming top-alignment to 4GB). Extend the mechanism to work with CBFS
regions residing elsewhere.
It's compatible with x86 because the default region there resides at the
old location, so things fall in place. It also makes more complex
layouts and non-x86 layouts work with negative base addresses.
Change-Id: Ibcde973d85bad5d1195d657559f527695478f46c
Signed-off-by: Patrick Georgi <pgeorgi(a)chromium.org>
---
util/cbfstool/cbfstool.c | 10 +++++++++-
1 file changed, 9 insertions(+), 1 deletion(-)
diff --git a/util/amdfwtool/amdfwtool.c b/util/amdfwtool/amdfwtool.c
index f958aba..b08a961 100644
--- a/util/amdfwtool/amdfwtool.c
+++ b/util/amdfwtool/amdfwtool.c
@@ -377,6 +377,9 @@ int main(int argc, char **argv)
current = AMD_ROMSIG_OFFSET;
amd_romsig = rom + AMD_ROMSIG_OFFSET;
amd_romsig[0] = 0x55AA55AA; /* romsig */
+ amd_romsig[1] = 0;
+ amd_romsig[2] = 0;
+ amd_romsig[3] = 0;
current += 0x20; /* size of ROMSIG */
Martin Roth (martinroth(a)google.com) just uploaded a new patch set to gerrit, which you can find at https://review.coreboot.org/12684
-gerrit
commit 3bfced94ab3621c90a417199fdeb18d3ff00e336
Author: Martin Roth <martinroth(a)google.com>
Date: Mon Dec 7 16:50:47 2015 -0700
soc/intel/fsp_baytrail: Adjust root port INT routing
Adjust the root port INT routing based on Bay Trail spec:
Document Number: 538136, Rev. 3.9
Table 241. Interrupt Generated for INT[A-D] Interrupts
INTA INTB INTC INTD
Root Port 1 INTA# INTB# INTC# INTD#
Root Port 2 INTD# INTA# INTB# INTC#
Root Port 3 INTC# INTD# INTA# INTB#
Root Port 4 INTB# INTC# INTD# INTA#
Change-Id: I22a8c0bc6ad731dfb79385d6e165f1ec0a07507d
Signed-off-by: Martin Roth <martinroth(a)google.com>
---
src/soc/intel/fsp_baytrail/southcluster.c | 9 +++++++++
1 file changed, 9 insertions(+)
diff --git a/src/soc/intel/fsp_baytrail/southcluster.c b/src/soc/intel/fsp_baytrail/southcluster.c
index 6182948..a49f6d7 100644
--- a/src/soc/intel/fsp_baytrail/southcluster.c
+++ b/src/soc/intel/fsp_baytrail/southcluster.c
@@ -208,6 +208,15 @@ static void write_pci_config_irqs(void)
if (targ_dev == NULL || new_int_pin < 1)
continue;
+ /*
+ * Adjust the INT routing for the PCIe root ports
+ * See 'Interrupt Generated for INT[A-D] Interrupts'
+ * Table 241 in Document Number: 538136, Rev. 3.9
+ */
+ if (PCI_SLOT(targ_dev->path.pci.devfn) == PCIE_DEV)
+ new_int_pin = (new_int_pin +
+ PCI_FUNC(targ_dev->path.pci.devfn)) % 4;
+
/* Get the original INT_PIN for record keeping */
original_int_pin = pci_read_config8(irq_dev, PCI_INTERRUPT_PIN);
the following patch was just integrated into master:
commit 6215b88aee845046a73613f1508e6fa779427add
Author: Martin Roth <martinroth(a)google.com>
Date: Fri Nov 27 11:35:54 2015 -0700
northbridge/amd/agesa/agesawrapper.c: Fix Kconfig symbols
The Kconfig symbols were missing an underscore, so were not getting
evaluated properly.
Change-Id: I619cf3f44f44f9c9699482d64164d3db28cd4c8f
Signed-off-by: Martin Roth <martinroth(a)google.com>
Reviewed-on: https://review.coreboot.org/12559
Tested-by: build bot (Jenkins)
Reviewed-by: Kyösti Mälkki <kyosti.malkki(a)gmail.com>
Reviewed-by: Paul Menzel <paulepanter(a)users.sourceforge.net>
See https://review.coreboot.org/12559 for details.
-gerrit
the following patch was just integrated into master:
commit e1e9ed37daa4d8fa3aa367a16300408185a63e43
Author: Zheng Bao <fishbaozi(a)gmail.com>
Date: Mon Dec 7 22:59:45 2015 +0800
AMD/bettong: Remove the useless period (trivial)
It seems that no one add period in Kconfig.
Change-Id: Ie9c585a8e6f1a73036b92b2873dc19284d82dc39
Signed-off-by: Zheng Bao <fishbaozi(a)gmail.com>
Reviewed-on: https://review.coreboot.org/12668
Reviewed-by: Martin Roth <martinroth(a)google.com>
Tested-by: build bot (Jenkins)
See https://review.coreboot.org/12668 for details.
-gerrit
the following patch was just integrated into master:
commit b790fe944d7533b65b37885e0aae43d9826e2086
Author: Martin Roth <martinroth(a)google.com>
Date: Thu Dec 3 14:02:16 2015 -0700
intel/littleplains: Update with recent changes to mohonpeak
- Change SEABIOS_MALLOC_UPPERMEMORY to using PAYLOAD_CONFIGFILE.
- Add saved seabios .config with CONFIG_MALLOC_UPPERMEMORY unset.
- Remove fixed microcode location.
Change-Id: I8b723edf6d6b5542f118e9e0e1aee8104d9cde86
Signed-off-by: Martin Roth <martinroth(a)google.com>
Reviewed-on: https://review.coreboot.org/12635
Tested-by: build bot (Jenkins)
Reviewed-by: David Guckian <david.guckian(a)intel.com>
See https://review.coreboot.org/12635 for details.
-gerrit
the following patch was just integrated into master:
commit b9de78beb67fdf5057e01af7aae198eaacb76d14
Author: Martin Roth <martinroth(a)google.com>
Date: Thu Dec 3 14:27:45 2015 -0700
intel/common/firmware: Add option to configure SPI for EM100
Add a Kconfig option to set the firmware descriptor to allow EM100 use.
Change-Id: If5d7cd6ad671f0328ee5be0b5e660dbc837fcac3
Signed-off-by: Martin Roth <martinroth(a)google.com>
Reviewed-on: https://review.coreboot.org/12637
Tested-by: build bot (Jenkins)
Reviewed-by: Aaron Durbin <adurbin(a)chromium.org>
See https://review.coreboot.org/12637 for details.
-gerrit
Patrick Georgi (pgeorgi(a)google.com) just uploaded a new patch set to gerrit, which you can find at https://review.coreboot.org/12683
-gerrit
commit 6a8c7dafe6bd2937b53ac06b656bd3bff9634829
Author: Patrick Georgi <pgeorgi(a)chromium.org>
Date: Mon Dec 7 23:14:07 2015 +0100
cbfstool: make top-aligned address work per-region
The former interpretation sprung from the x86 way of doing things
(assuming top-alignment to 4GB). Extend the mechanism to work with CBFS
regions residing elsewhere.
It's compatible with x86 because the default region there resides at the
old location, so things fall in place. It also makes more complex
layouts and non-x86 layouts work with negative base addresses.
Change-Id: Ibcde973d85bad5d1195d657559f527695478f46c
Signed-off-by: Patrick Georgi <pgeorgi(a)chromium.org>
---
util/cbfstool/cbfstool.c | 6 +++++-
1 file changed, 5 insertions(+), 1 deletion(-)
diff --git a/util/cbfstool/cbfstool.c b/util/cbfstool/cbfstool.c
index fb4c8b5..ba98667 100644
--- a/util/cbfstool/cbfstool.c
+++ b/util/cbfstool/cbfstool.c
@@ -101,7 +101,7 @@ static bool region_is_modern_cbfs(const char *region)
/*
* Converts between offsets from the start of the specified image region and
* "top-aligned" offsets from the top of the entire flash image. Works in either
* direction: pass in one type of offset and receive the other type.
* N.B. A top-aligned offset is always a positive number, and should not be
* confused with a top-aliged *address*, which is its arithmetic inverse. */
@@ -110,6 +110,14 @@ static unsigned convert_to_from_top_aligned(const struct buffer *region,
{
assert(region);
+ /* cover the situation where a negative base address is given by the
+ * user. Callers of this function negate it, so it'll be a positive
+ * number smaller than the region.
+ */
+ if ((offset > 0) && (offset < region->size)) {
+ return region->size - offset;
+ }
+
size_t image_size = partitioned_file_total_size(param.image_file);
return image_size - region->offset - offset;
}
the following patch was just integrated into master:
commit 85f362e9b6ec69ead84f22d5cf0f5f1995d08b6d
Author: zbao <fishbaozi(a)gmail.com>
Date: Mon Dec 7 05:17:23 2015 -0500
amdfwtool: Fill the first 3 romsig entries as 0
I didn't go back through the development guide for this.
But based on test, if the empty entry is filled as 0xFFFFFFFF,
instead of 0, the USB3 port can not be used.
Leave the entries of PSP and PSP2 as 0xFFFFFFFF to be compliant
with the case before the amdfwtool is used.
Change-Id: Icd5f9891e541279dbd551bbceaf091488d22bfef
Signed-off-by: Zheng Bao <fishbaozi(a)gmail.com>
Reviewed-on: https://review.coreboot.org/12665
Tested-by: build bot (Jenkins)
Reviewed-by: Martin Roth <martinroth(a)google.com>
See https://review.coreboot.org/12665 for details.
-gerrit
Zheng Bao (zheng.bao(a)amd.com) just uploaded a new patch set to gerrit, which you can find at https://review.coreboot.org/12665
-gerrit
commit e2dda328d9d160f5f93c4c3ca435be909f43a731
Author: zbao <fishbaozi(a)gmail.com>
Date: Mon Dec 7 05:17:23 2015 -0500
amdfwtool: Fill the first 3 romsig entries as 0
I didn't go back through the development guide for this.
But based on test, if the empty entry is filled as 0xFFFFFFFF,
instead of 0, the USB3 port can not be used.
Leave the entries of PSP and PSP2 as 0xFFFFFFFF to be compliant
with the case before the amdfwtool is used.
Change-Id: Icd5f9891e541279dbd551bbceaf091488d22bfef
Signed-off-by: Zheng Bao <fishbaozi(a)gmail.com>
---
util/amdfwtool/amdfwtool.c | 3 +++
1 file changed, 3 insertions(+)
@@ -101,7 +101,7 @@ static bool region_is_modern_cbfs(const char *region)
/*
* Converts between offsets from the start of the specified image region and
- * "top-aligned" offsets from the top of the entire flash image. Works in either
+ * "top-aligned" offsets from the top of the image region. Works in either
* direction: pass in one type of offset and receive the other type.
* N.B. A top-aligned offset is always a positive number, and should not be
diff --git a/util/cbfstool/cbfstool.c b/util/cbfstool/cbfstool.c
index fb4c8b5..79c2277 100644
--- a/util/cbfstool/cbfstool.c
+++ b/util/cbfstool/cbfstool.c
@@ -101,7 +101,7 @@ static bool region_is_modern_cbfs(const char *region)
/*
* Converts between offsets from the start of the specified image region and
* "top-aligned" offsets from the top of the entire flash image. Works in either
* direction: pass in one type of offset and receive the other type.
* N.B. A top-aligned offset is always a positive number, and should not be
* confused with a top-aliged *address*, which is its arithmetic inverse. */
@@ -110,6 +110,10 @@ static unsigned convert_to_from_top_aligned(const struct buffer *region,
{
assert(region);
+ if ((offset > 0) && (offset < region->size)) {
+ return region->size - offset;
+ }
+
size_t image_size = partitioned_file_total_size(param.image_file);
return image_size - region->offset - offset;
}
@@ -101,7 +101,7 @@ static bool region_is_modern_cbfs(const char *region)
/*
* Converts between offsets from the start of the specified image region and
- * "top-aligned" offsets from the top of the entire flash image. Works in either
+ * "top-aligned" offsets from the top of the image region. Works in either
* direction: pass in one type of offset and receive the other type.
* N.B. A top-aligned offset is always a positive number, and should not be